@@ -6,7 +6,7 @@
 
   ==============================================================================
 
-   Copyright (C) 1998 - 2024 Rachid Touzani
+   Copyright (C) 1998 - 2025 Rachid Touzani
 
    This file is part of OFELI.
 
@@ -40,15 +40,6 @@
 #include "linear_algebra/GraphOfMatrix.h"
 #include "solvers/LinearSolver.h"
 
-#ifdef USE_EIGEN
-#include <Eigen/Dense>
-#include <Eigen/Sparse>
-
-typedef Eigen::Matrix<T_,Eigen::Dynamic,1> VectorX;
-typedef SparseMatrix<T_>                   SpMat;
-typedef Triplet<real_t>                    Tr;
-#endif
-
 namespace OFELI {
 
 template<class T_>
@@ -75,9 +66,6 @@ SpMatrix<T_>::SpMatrix(size_t nr,
    if (_msize.nb_rows==_msize.nb_cols)
       _msize.size = _msize.nb_rows;
    _msize.length = _msize.nb_rows*_msize.nb_cols;
-#ifdef USE_EIGEN
-   _A.resize(_msize.nb_rows,_msize.nb_cols);
-#else
    _row_ptr.resize(_msize.nb_rows+1);
    _col_ind.resize(_msize.length);
    _row_ptr[0] = 0;
@@ -88,7 +76,6 @@ SpMatrix<T_>::SpMatrix(size_t nr,
       for (size_t j=0; j<_msize.nb_cols; j++)
          _col_ind[l++] = j+1;
    _a.resize(_msize.length,T_(0.));
-#endif
    _max_it = 1000;
    _toler = 1.e-8;
 }
@@ -102,9 +89,6 @@ SpMatrix<T_>::SpMatrix(size_t size,
    _msize.mt = SPARSE;
    _is_diagonal = is_diagonal;
    _msize.nb_rows = _msize.nb_cols = _msize.size = size;
-#ifdef USE_EIGEN
-   _A.resize(_msize.nb_rows,_msize.nb_cols);
-#else
    _msize.length = _msize.size*_msize.size;
    _row_ptr.resize(_msize.nb_rows+1);
    _col_ind.resize(_msize.length);
@@ -116,7 +100,6 @@ SpMatrix<T_>::SpMatrix(size_t size,
       for (size_t j=0; j<_msize.nb_cols; j++)
          _col_ind[l++] = j+1;
    _a.resize(_msize.length,T_(0.));
-#endif
    _max_it = 1000;
    _toler = 1.e-8;
 }
@@ -149,7 +132,6 @@ SpMatrix<T_>::SpMatrix(size_t dof,
    _toler = 1.e-8;
 }
 
-#ifndef USE_EIGEN
 template<class T_>
 SpMatrix<T_>::SpMatrix(size_t dof,
                        size_t nb_eq,
@@ -162,9 +144,7 @@ SpMatrix<T_>::SpMatrix(size_t dof,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
-#ifndef USE_EIGEN
 template<class T_>
 SpMatrix<T_>::SpMatrix(const vector<RC>& I,
                        int               opt)
@@ -176,9 +156,8 @@ SpMatrix<T_>::SpMatrix(const vector<RC>& I,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
-#ifndef USE_EIGEN
+
 template<class T_>
 SpMatrix<T_>::SpMatrix(const vector<RC>& I,
                        const Vect<T_>&   a,
@@ -210,9 +189,7 @@ SpMatrix<T_>::SpMatrix(const vector<RC>& I,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
-#ifndef USE_EIGEN
 template<class T_>
 SpMatrix<T_>::SpMatrix(size_t                nr,
                        size_t                nc,
@@ -235,9 +212,8 @@ SpMatrix<T_>::SpMatrix(size_t                nr,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
-#ifndef USE_EIGEN
+
 template<class T_>
 SpMatrix<T_>::SpMatrix(size_t                nr,
                        size_t                nc,
@@ -262,9 +238,8 @@ SpMatrix<T_>::SpMatrix(size_t                nr,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
-#ifndef USE_EIGEN
+
 template<class T_>
 SpMatrix<T_>::SpMatrix(const vector<size_t>& row_ptr,
                        const vector<size_t>& col_ind)
@@ -283,9 +258,8 @@ SpMatrix<T_>::SpMatrix(const vector<size_t>& row_ptr,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
-#ifndef USE_EIGEN
+
 template<class T_>
 SpMatrix<T_>::SpMatrix(const vector<size_t>& row_ptr,
                        const vector<size_t>& col_ind,
@@ -306,7 +280,6 @@ SpMatrix<T_>::SpMatrix(const vector<size_t>& row_ptr,
    _max_it = 1000;
    _toler = 1.e-8;
 }
-#endif
 
 
 template<class T_>
@@ -317,27 +290,18 @@ SpMatrix<T_>::SpMatrix(const SpMatrix& m)
    _dof = m._dof;
    _is_dense = m._is_dense;
    _extended = m._extended;
-#ifdef USE_EIGEN
-   if (_msize.nb_rows)
-      _A.resize(_msize.nb_rows,_msize.nb_cols);
-#else
    _row_ptr.resize(_msize.size+1);
    _col_ind.resize(_msize.length);
    _col_ind = m._col_ind;
    _row_ptr = m._row_ptr;
    _a.resize(_msize.length);
    _a = m._a;
-#endif
    _diag.resize(_msize.size);
    _diag = m._diag;
    _solver = -1;
    _prec = -1;
    _max_it = 1000;
    _toler = 1.e-8;
-   _solver = -1;
-   _prec = -1;
-   _max_it = 1000;
-   _toler = 1.e-8;
 }
 
 
@@ -350,28 +314,17 @@ template<class T_>
 void SpMatrix<T_>::Dense()
 {
    _is_dense = 1;
-#ifdef USE_EIGEN
-   _msize.length = _msize.nb_rows*_msize.nb_cols;
-   _A.reserve(_msize.length);
-   clear();
-#endif
 }
 
 
 template<class T_>
 void SpMatrix<T_>::Identity()
 {
-#ifdef USE_EIGEN
-   _A.reserve(_msize.length);
-   for (size_t i=0; i<_msize.nb_rows; i++)
-      _A.coeffRef(i,i) = static_cast<T_>(1.);
-#else
    for (size_t i=0; i<_msize.nb_rows; ++i) {
       for (size_t j=0; j<_row_ptr[i+1]-_row_ptr[i]; ++j)
          _a[_row_ptr[i]+j-1] = static_cast<T_>(0.);
       _a[_row_ptr[i]+i-1] = static_cast<T_>(1.);
    }
-#endif
 }
 
 
@@ -380,32 +333,19 @@ void SpMatrix<T_>::Diagonal()
 {
    _is_dense = 0;
    _is_diagonal = 1;
-#ifdef USE_EIGEN
-   _msize.length = _msize.nb_rows;
-   _A.reserve(_msize.length);
-   for (size_t i=0; i<_msize.nb_rows; i++)
-      _A.insert(i,i) = 0;
-#else
    for (size_t i=0; i<_msize.length; i++)
       _a[i] = static_cast<T_>(0);
-#endif
 }
 
 
 template<class T_>
 void SpMatrix<T_>::Diagonal(const T_& a)
 {
-#ifdef USE_EIGEN
-   _A.reserve(_msize.length);
-   for (size_t i=0; i<_msize.nb_rows; i++)
-      _A.coeffRef(i,i) = a;
-#else
    for (size_t i=0; i<_msize.nb_rows; ++i) {
       for (size_t j=0; j<_row_ptr[i+1]-_row_ptr[i]; ++j)
          _a[_row_ptr[i]+j-1] = 0;
       _a[_row_ptr[i]+i-1] = a;
    }
-#endif
 }
 
 
@@ -416,22 +356,6 @@ inline void SpMatrix<real_t>::Laplace2D(size_t nx,
    _is_dense = 0;
    _is_diagonal = 0;
    _msize.size = _msize.nb_rows = _msize.nb_cols = nx*ny;
-#ifdef USE_EIGEN
-   _msize.length = 5*_msize.size;
-   _A.reserve(_msize.length);
-   for (size_t ii=0; ii<_msize.size; ii++) {
-      _A.insert(ii,ii) =  4.;
-      size_t i=ii/ny, j=ii-i*ny;
-      if (i>0)
-         _A.insert(ii,ii-ny) = -1.;
-      if (i<nx-1)
-         _A.insert(ii,ii+ny) = -1.;
-      if (j>0)
-         _A.insert(ii,ii- 1) = -1.;
-      if (j<ny-1)
-         _A.insert(ii,ii+ 1) = -1.;
-   }
-#else
    _row_ptr.push_back(0);
    _msize.length = 0;
    for (size_t ii=0; ii<_msize.size; ii++) {
@@ -461,7 +385,6 @@ inline void SpMatrix<real_t>::Laplace2D(size_t nx,
       }
       _row_ptr.push_back(_msize.length);
    }
-#endif
 }
 
 
@@ -485,13 +408,7 @@ void SpMatrix<T_>::setMesh(Mesh&  mesh,
       _msize.length = ElementGraph(mesh,_row_ptr,_col_ind,_msize.IJ,_nbc);
    else
       ;
-#ifdef USE_EIGEN
-   _A.resize(_msize.size,_msize.size);
-   _A.reserve(_nbc);
-   clear();
-#else
    _a.resize(_msize.length,static_cast<T_>(0));
-#endif
    _diag.resize(_msize.size);
 }
 
@@ -508,13 +425,7 @@ void SpMatrix<T_>::setMesh(size_t dof,
       _msize.length = XGraph(mesh,_row_ptr,_col_ind,_msize.IJ,_nbc);
    else
       _msize.length = NodeGraphScal(mesh,_row_ptr,_col_ind,_msize.IJ,_nbc);
-#ifdef USE_EIGEN
-   _A.resize(_msize.size,_msize.size);
-   _A.reserve(_nbc);
-   clear();
-#else
    _a.resize(_msize.length,T_(0.));
-#endif
    _diag.resize(_msize.size);
 }
 
@@ -528,13 +439,7 @@ void SpMatrix<T_>::setMesh(size_t dof,
    _dof = 0;
    _msize.nb_rows = _msize.nb_cols = _msize.size = nb_eq;
    _msize.length = NodeGraphScal(mesh,dof,nb_eq,_row_ptr,_col_ind,_msize.IJ,_nbc);
-#ifdef USE_EIGEN
-   _A.resize(_msize.size,_msize.size);
-   _A.reserve(_nbc);
-   clear();
-#else
    _a.resize(_msize.length,T_(0.));
-#endif
    _diag.resize(_msize.size);
 }
 
@@ -560,13 +465,7 @@ void SpMatrix<T_>::setMesh(Mesh&  mesh,
       _msize.length = ElementGraph(mesh,_row_ptr,_col_ind,_msize.IJ,_nbc);
    else
       ;
-#ifdef USE_EIGEN
-   _A.resize(_msize.size,_msize.size);
-   _A.reserve(_nbc);
-   clear();
-#else
    _a.resize(_msize.length,T_(0.));
-#endif
    _diag.resize(_msize.size);
 }
 
@@ -595,10 +494,6 @@ void SpMatrix<T_>::setSides()
 template<class T_>
 void SpMatrix<T_>::setDiag()
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.nb_rows; i++)
-      _diag[i] = _A.coeff(i,i);
-#else
    for (size_t i=0; i<_msize.size; i++) {
       for (size_t j=0; j<_row_ptr[i+1]-_row_ptr[i]; j++) {
          if (i==j) {
@@ -607,7 +502,6 @@ void SpMatrix<T_>::setDiag()
          }
       }
    }
-#endif
 }
 
 
@@ -619,7 +513,6 @@ void SpMatrix<T_>::DiagPrescribe(Mesh&           mesh,
    real_t p = 0.;
    for (size_t j=1; j<=_msize.nb_rows; j++)
       p = std::max(p,Abs(get(j,j)));
-#if !defined(USE_EIGEN)
    size_t k=0;
    node_loop(&mesh) {
       for (size_t i=1; i<=The_node.getNbDOF(); ++i) {
@@ -633,7 +526,6 @@ void SpMatrix<T_>::DiagPrescribe(Mesh&           mesh,
             }
       }
    }
-#endif
 }
 
 
@@ -641,7 +533,6 @@ template<class T_>
 void SpMatrix<T_>::DiagPrescribe(Vect<T_>&       b,
                                  const Vect<T_>& u)
 {
-#if !defined(USE_EIGEN)
    real_t p = 0;
    for (size_t j=1; j<=_msize.nb_rows; j++)
       p = std::max(p,Abs(get(j,j)));
@@ -658,7 +549,6 @@ void SpMatrix<T_>::DiagPrescribe(Vect<T_>&       b,
             }
       }
    }
-#endif
 }
 
 
@@ -666,9 +556,6 @@ template<class T_>
 void SpMatrix<T_>::setSize(size_t size)
 {
    _msize.nb_rows = _msize.nb_cols = _msize.size = size;
-#ifdef USE_EIGEN
-   _A.resize(size,size);
-#else
    _msize.length = lsize_t(_msize.nb_rows*_msize.nb_cols);
    _row_ptr.resize(_msize.nb_rows+1);
    _col_ind.resize(_msize.length);
@@ -680,7 +567,6 @@ void SpMatrix<T_>::setSize(size_t size)
       for (size_t j=0; j<_msize.nb_cols; j++)
          _col_ind[l++] = j+1;
    _a.resize(_msize.length,T_(0.));
-#endif
 }
 
 
@@ -694,9 +580,6 @@ void SpMatrix<T_>::setSize(size_t nr,
    if (_msize.nb_rows==_msize.nb_cols)
       _msize.size = _msize.nb_rows;
    _msize.length = lsize_t(_msize.nb_rows*_msize.nb_cols);
-#ifdef USE_EIGEN
-   _A.resize(nr,nc);
-#else
    _row_ptr.resize(_msize.nb_rows+1);
    _col_ind.resize(_msize.length);
    _row_ptr[0] = 1;
@@ -707,7 +590,6 @@ void SpMatrix<T_>::setSize(size_t nr,
       for (size_t j=0; j<_msize.nb_cols; j++)
          _col_ind[l++] = j + 1;
    _a.resize(_msize.length,T_(0.));
-#endif
 }
 
 
@@ -733,14 +615,7 @@ void SpMatrix<T_>::setGraph(const vector<RC>& I,
    _row_ptr.resize(_msize.size+1);
    _col_ind.resize(_msize.length);
    StoreGraph(_msize.IJ,_row_ptr,_col_ind);
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_row_ptr.size()-1; i++)
-      _nbc.push_back(_row_ptr[i+1]-_row_ptr[i]);
-   _A.reserve(_nbc);
-   clear();
-#else
    _a.resize(_msize.length,0);
-#endif
 }
 
 
@@ -748,16 +623,8 @@ template<class T_>
 Vect<T_> SpMatrix<T_>::getRow(size_t i) const
 {
    Vect<T_> v(_msize.nb_cols);
-#ifdef USE_EIGEN
-   size_t j=0;
-   for (size_t k=0; k<_msize.length; k++) {
-      if (_msize.IJ[k].first==i-1)
-         v[j++] = _A.coeff(_msize.IJ[k].first,_msize.IJ[k].second);
-   }
-#else
    for (size_t j=1; j<=_msize.nb_cols; j++)
       v(j) = get(i,j);
-#endif
    return v;
 }
 
@@ -766,16 +633,8 @@ template<class T_>
 Vect<T_> SpMatrix<T_>::getColumn(size_t j) const
 {
    Vect<T_> v(_msize.nb_rows);
-#ifdef USE_EIGEN
-   size_t i=0;
-   for (size_t k=0; k<_msize.length; k++) {
-      if (_msize.IJ[k].second==j-1)
-         v[i++] = _A.coeff(_msize.IJ[k].first,_msize.IJ[k].second);
-   }
-#else
    for (size_t i=1; i<=_msize.nb_rows; i++)
       v(i) = get(i,j);
-#endif
    return v;
 }
 
@@ -784,15 +643,11 @@ template<class T_>
 T_ SpMatrix<T_>::at(size_t i,
                     size_t j)
 {
-#ifdef USE_EIGEN
-   return _A.coeffRef(i-1,j-1);
-#else
    int k=_col_index(i,j);
    if (k<0)
       return static_cast<T_>(0);
    else
       return _a[_row_ptr[i-1]+k];
-#endif
 }
 
 
@@ -800,9 +655,6 @@ template<class T_>
 T_& SpMatrix<T_>::operator()(size_t i,
                              size_t j)
 {
-#ifdef USE_EIGEN
-   return _A.coeffRef(i-1,j-1);
-#else
    int k=_col_index(i,j);
    if (k<0)
       throw OFELIException("In SpMatrix::set(i,j,x): Index pair: (" + to_string(i) +
@@ -810,7 +662,6 @@ T_& SpMatrix<T_>::operator()(size_t i,
    else
       return _a[_row_ptr[i-1]+k];
    return _temp;
-#endif
 }
 
 
@@ -818,15 +669,11 @@ template<class T_>
 T_ SpMatrix<T_>::operator()(size_t i,
                             size_t j) const
 {
-#ifdef USE_EIGEN
-   return _A.coeff(i-1,j-1);
-#else
    int k=_col_index(i,j);
    if (k<0)
       return static_cast<T_>(0);
    else
       return _a[_row_ptr[i-1]+k];
-#endif
 }
 
 
@@ -843,12 +690,7 @@ Vect<T_> SpMatrix<T_>::operator*(const Vect<T_>& x) const
 {
    Vect<T_> y(_msize.nb_rows);
    y.clear();
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      y[_msize.IJ[i].first] += _A.coeff(_msize.IJ[i].first,_msize.IJ[i].second)*x[_msize.IJ[i].second];
-#else
    Mult(x,y);
-#endif
    return y;
 }
 
@@ -856,13 +698,8 @@ Vect<T_> SpMatrix<T_>::operator*(const Vect<T_>& x) const
 template<class T_>
 SpMatrix<T_>& SpMatrix<T_>::operator*=(const T_& a)
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      _A.coeffRef(_msize.IJ[i].first,_msize.IJ[i].second) *= a;
-#else
    for (size_t k=0; k<_msize.length; ++k)
       _a[k] *= a;
-#endif
    return *this;
 }
 
@@ -870,7 +707,6 @@ SpMatrix<T_>& SpMatrix<T_>::operator*=(const T_& a)
 template<class T_>
 void SpMatrix<T_>::getMesh(Mesh& mesh)
 {
-#if !defined(USE_EIGEN)
    if (_sides)
        SideGraph(mesh,_row_ptr,_col_ind);
    else {
@@ -885,7 +721,6 @@ void SpMatrix<T_>::getMesh(Mesh& mesh)
           NodeGraph(mesh,_row_ptr,_col_ind,_msize.IJ,_nbc);
    }
    _a.resize(_msize.length,T_(0.));
-#endif
    _diag.resize(_msize.size);
 }
 
@@ -894,13 +729,8 @@ template<class T_>
 void SpMatrix<T_>::Mult(const Vect<T_>& x,
                         Vect<T_>&       y) const
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      y[_msize.IJ[i].first] = _A.coeff(_msize.IJ[i].first,_msize.IJ[i].second)*x[_msize.IJ[i].second];
-#else
    y = static_cast<T_>(0);
    MultAdd(x,y);
-#endif
 }
 
 
@@ -908,15 +738,10 @@ template<class T_>
 void SpMatrix<T_>::MultAdd(const Vect<T_>& x,
                            Vect<T_>&       y) const
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      y[_msize.IJ[i].first] += _A.coeff(_msize.IJ[i].first,_msize.IJ[i].second)*x[_msize.IJ[i].second];
-#else
    size_t l=0;
    for (size_t i=0; i<_msize.nb_rows; ++i)
       for (size_t j=0; j<_row_ptr[i+1]-_row_ptr[i]; ++j)
          y[i] += _a[_row_ptr[i]+j] * x[_col_ind[l++]-1];
-#endif
 }
 
 
@@ -925,15 +750,10 @@ void SpMatrix<T_>::MultAdd(T_              a,
                            const Vect<T_>& x,
                            Vect<T_>&       y) const
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      y[_msize.IJ[i].first] += a*_A.coeff(_msize.IJ[i].first,_msize.IJ[i].second)*x[_msize.IJ[i].second];
-#else
    size_t l=0;
    for (size_t i=0; i<_msize.nb_rows; i++)
       for (size_t j=0; j<_row_ptr[i+1]-_row_ptr[i]; j++)
          y[i] += a * _a[_row_ptr[i]+j] * x[_col_ind[l++]-1];
-#endif
 }
 
 
@@ -941,14 +761,9 @@ template<class T_>
 void SpMatrix<T_>::TMult(const Vect<T_>& x,
                          Vect<T_>&       y) const
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      y[_msize.IJ[i].first] += _A.coeff(_msize.IJ[i].second,_msize.IJ[i].first)*x[_msize.IJ[i].second];
-#else
    for (size_t i=0; i<_msize.nb_rows; i++)
       for (size_t j=0; j<_row_ptr[i+1]-_row_ptr[i]; j++)
          y[_col_ind[j+_row_ptr[i]-1]] += _a[_row_ptr[i]+j] * x[i];
-#endif
 }
 
 
@@ -956,11 +771,7 @@ template<class T_>
 void SpMatrix<T_>:: Axpy(T_                  a,
                          const SpMatrix<T_>& m)
 {
-#ifdef USE_EIGEN
-   _A += a * m._A;
-#else
    _a += a * m._a;
-#endif
 }
 
 
@@ -975,16 +786,12 @@ void SpMatrix<T_>::set(size_t    i,
                        size_t    j,
                        const T_& val)
 {
-#ifdef USE_EIGEN
-   _A.coeffRef(i-1,j-1) = val;
-#else
    int k=_col_index(i,j);
    if (k<0)
       throw OFELIException("In SpMatrix::set(i,j,x): Index pair (" + to_string(i) +
                            "," + to_string(j) + ") not compatible with sparse storage.");
    else
       _a[_row_ptr[i-1]+k] = val;
-#endif
 }
 
 
@@ -993,27 +800,15 @@ void SpMatrix<T_>::add(size_t    i,
                        size_t    j,
                        const T_& val)
 {
-#ifdef USE_EIGEN
-   _A.coeffRef(i-1,j-1) += val;
-#else
    _a[_row_ptr[i-1]+_col_index(i,j)] += val;
-#endif
 }
 
 
 template<class T_>
 void SpMatrix<T_>::operator=(const T_& x)
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++) {
-      _A.coeffRef(_msize.IJ[i].first,_msize.IJ[i].second) = static_cast<T_>(0);
-      if (_msize.IJ[i].first==_msize.IJ[i].second)
-         _A.coeffRef(_msize.IJ[i].first,_msize.IJ[i].first) = x;	
-}
-#else
    for (size_t i=0; i<_msize.length; ++i)
       _a[i] = x;
-#endif
 }
 
 
@@ -1038,11 +833,6 @@ int SpMatrix<T_>::Factor()
 }
 
 
-#ifdef USE_EIGEN
-template<class T_>
-int SpMatrix<T_>::DILUFactorize(vector<size_t>& id,
-                                vector<T_>& pivot) const;
-#else
 template<class T_>
 int SpMatrix<T_>::DILUFactorize(vector<size_t>& id,
                                 vector<T_>&     pivot) const
@@ -1078,27 +868,16 @@ int SpMatrix<T_>::DILUFactorize(vector<size_t>& id,
    }
    return 0;
 }
-#endif
 
 
-#ifdef USE_EIGEN
 template<class T_>
 int SpMatrix<T_>::ILUFactorize(vector<size_t>& id,
                                vector<T_>& pivot) const
 {
    return DILUFactorize(id,pivot);
 }
-#else
-template<class T_>
-int SpMatrix<T_>::ILUFactorize(vector<size_t>& id,
-                               vector<T_>& pivot) const
-{
-   return DILUFactorize(id,pivot);
-}
-#endif
 
 
-#ifndef USE_EIGEN
 template<class T_>
 void SpMatrix<T_>::DILUSolve(const vector<size_t>& id,
                              const vector<T_>&     pivot,
@@ -1119,10 +898,8 @@ void SpMatrix<T_>::DILUSolve(const vector<size_t>& id,
       x[_msize.size-i-1] = z[_msize.size-i-1] - pivot[_msize.size-i-1] * s;
    }
 }
-#endif
 
 
-#ifndef USE_EIGEN
 template<class T_>
 void SpMatrix<T_>::ILUSolve(const vector<size_t>& id,
                             const vector<T_>&     pivot,
@@ -1131,10 +908,8 @@ void SpMatrix<T_>::ILUSolve(const vector<size_t>& id,
 {
    DILUSolve(id,pivot,b,x);
 }
-#endif
 
 
-#ifndef USE_EIGEN
 template<class T_>
 void SpMatrix<T_>::SSORSolve(const Vect<T_>& b,
                              Vect<T_>&       x) const
@@ -1165,7 +940,6 @@ void SpMatrix<T_>::SSORSolve(const Vect<T_>& b,
       x[i] = z[i] - s/_a[id[i]-1];
    }
 }
-#endif
 
 
 template<class T_>
@@ -1207,13 +981,8 @@ void SpMatrix<T_>::setSolver(Iteration      solver,
 template<class T_>
 void SpMatrix<T_>::clear()
 {
-#ifdef USE_EIGEN
-   for (size_t i=0; i<_msize.length; i++)
-      _A.coeffRef(_msize.IJ[i].first,_msize.IJ[i].second) = static_cast<T_>(0);
-#else
    for (size_t i=0; i<_msize.length; ++i)
       _a[i] = static_cast<T_>(0);
-#endif
 }
 
 
@@ -1228,26 +997,14 @@ template<class T_>
 T_ SpMatrix<T_>::get(size_t i,
                      size_t j) const
 {
-#ifdef USE_EIGEN
-   return _A.coeff(i-1,j-1);
-#else
    int k=_col_index(i,j);
    if (k<0)
       return static_cast<T_>(0);
    else
       return _a[_row_ptr[i-1]+k-1];
-#endif
 }
 
-#ifdef USE_EIGEN
-template<class T_>
-SpMat& SpMatrix<T_>::getEigenMatrix()
-{
-   return _A;
-}
-#endif
 
-#if !defined(USE_EIGEN)
 template<class T_>
 int SpMatrix<T_>::_col_index(size_t i, size_t j) const
 {
@@ -1256,7 +1013,6 @@ int SpMatrix<T_>::_col_index(size_t i, size_t j) const
          return k;
    return -1;
 }
-#endif
 
 
 template<class T_>
@@ -1274,19 +1030,6 @@ inline void SpMatrix<real_t>::Laplace1D(size_t n,
    _is_dense = 0;
    _is_diagonal = 0;
    _msize.size = _msize.nb_rows = _msize.nb_cols = n;
-#ifdef USE_EIGEN
-   _msize.length = 3*_msize.size - 2;
-   _A.reserve(_msize.length);
-   _A.insert(0,0) =  2./h;
-   _A.insert(0,1) = -1./h;
-   for (size_t i=1; i<_msize.nb_rows-1; i++) {
-      _A.insert(i,i-1) = -1./h;
-      _A.insert(i,i  ) =  2./h;
-      _A.insert(i,i+1) = -1./h;
-   }
-   _A.insert(_msize.nb_rows-1,_msize.nb_rows-2) = -1./h;
-   _A.insert(_msize.nb_rows-1,_msize.nb_rows-1) =  2./h;
-#else
    _row_ptr.push_back(0);
    _row_ptr.push_back(2);
    _col_ind.push_back(1);
@@ -1308,7 +1051,6 @@ inline void SpMatrix<real_t>::Laplace1D(size_t n,
    _a.push_back(-1./h);
    _a.push_back( 2./h);
    _msize.length = _row_ptr[_msize.size];
-#endif
 }
 
 
@@ -1325,9 +1067,6 @@ template<class T_>
 ostream& operator<<(ostream&            s,
                     const SpMatrix<T_>& A)
 {
-#ifdef USE_EIGEN
-   s << endl << A._A << endl;
-#else
    s.setf(ios::right|ios::scientific);
    s << endl;
    size_t k = 0;
@@ -1336,7 +1075,6 @@ ostream& operator<<(ostream&            s,
          s << "(" << setw(6) << i+1 << "," << setw(6) << A._col_ind[j] << "): "
            << setprecision(8) << std::setfill(' ') << setw(18) << A._a[k++] << endl;
    }
-#endif
    return s;
 }
 
@@ -1344,4 +1082,4 @@ ostream& operator<<(ostream&            s,
 
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
-#endif
+#endif
\ No newline at end of file
