@@ -6,7 +6,7 @@
 
   ==============================================================================
 
-    Copyright (C) 2021 - 2024 Rachid Touzani
+    Copyright (C) 2021 - 2025 Rachid Touzani
 
     This file is part of rita.
 
@@ -69,6 +69,7 @@ int optim::run()
    int count_lec=0, count_gec=0, count_eqc=0, count_vector=0, penal_ok=0, nb=0, key=0;
    double in=0., xx=0.;
    vector<string> grad, hess, var, le_cons, eq_cons;
+   vector<size_t> nbv;
    OFELI::Vect<double> *A_le, *A_ge, *A_eq;
    string str, J, name="", constr="";
    string fn="";
@@ -195,7 +196,7 @@ int optim::run()
          *_rita->ofh << " function=" << name;
       }
       else {
-         ind = _data->addVector(var_name[0],0.,size,"",false);
+         ind = _data->addVector(var_name[0],0.,size,"",SetCalc::SET);
          opt_var = _data->theVector[ind];
          if (size==1)
             var.push_back(var_name[0]);
@@ -475,7 +476,7 @@ int optim::run()
                   CHK_MSGR(!count_lp && lp,_pr+"end>","Missing objective function.")
                   CHK_MSGR(!count_vector,_pr+"end>","Missing a variable name.")
                   *_rita->ofh << "optimization\n  size " << size << endl << "  lp" << endl;
-                  ind = _data->addVector(var_name[0],0.,size,"",false);
+                  ind = _data->addVector(var_name[0],0.,size,"",SetCalc::SET);
                   opt_var = _data->theVector[ind];
                   if (size==1)
                      var.push_back(var_name[0]);
@@ -524,7 +525,7 @@ int optim::run()
                      *_rita->ofh << "  function " << name << endl;
                   }
                   else {
-                     ind = _data->addVector(var_name[0],0.,size,"",false);
+                     ind = _data->addVector(var_name[0],0.,size,"",SetCalc::SET);
                      if (size==1)
                         var.push_back(var_name[0]);
                      else {
@@ -634,7 +635,7 @@ int optim::run()
                break;
 
             default:
-               DEFAULT_KW
+               DEFAULT_KW(_rita)
          }
       }
    }
@@ -672,4 +673,4 @@ ostream& operator<<(ostream& s, const optim& o)
    return s;
 }
 
-} /* namespace RITA */
\ No newline at end of file
+} /* namespace RITA */
